Module cache

Module cache 

TX verification cache

Structs

CachedScriptCycles
Cached result of successful transaction script verification.
Completed
Completed contextual transaction verification.
Suspended
Suspended state
VerifyCacheKey
An opaque transaction verification cache key derived from a witness transaction hash.

Traits

TxVerificationCacheLookup
Lookup entries in a transaction verification cache by witness transaction hash.

Functions

init_cache
Initialize cache

Type Aliases

FetchedTxVerificationCache
Verification cache entries fetched for a batch of transactions.
TxVerificationCache
TX verification lru cache