TX verification cache
Structs
- Cached
Script Cycles - Cached result of successful transaction script verification.
- Completed
- Completed contextual transaction verification.
- Suspended
- Suspended state
- Verify
Cache Key - An opaque transaction verification cache key derived from a witness transaction hash.
Traits
- TxVerification
Cache Lookup - Lookup entries in a transaction verification cache by witness transaction hash.
Functions
- init_
cache - Initialize cache
Type Aliases
- Fetched
TxVerification Cache - Verification cache entries fetched for a batch of transactions.
- TxVerification
Cache - TX verification lru cache