TransactionError

Enum TransactionError 

pub enum TransactionError {
Show 16 variants InsufficientCellCapacity { inner: TransactionErrorSource, index: usize, occupied_capacity: Capacity, capacity: Capacity, }, OutputsSumOverflow { inputs_sum: Capacity, outputs_sum: Capacity, }, Empty { inner: TransactionErrorSource, }, DuplicateCellDeps { out_point: OutPoint, }, DuplicateHeaderDeps { hash: Byte32, }, OutputsDataLengthMismatch { outputs_len: usize, outputs_data_len: usize, }, InvalidSince { index: usize, }, Immature { index: usize, }, CellbaseImmaturity { inner: TransactionErrorSource, index: usize, }, MismatchedVersion { expected: u32, actual: u32, }, ExceededMaximumBlockBytes { limit: u64, actual: u64, }, Compatible { feature: &'static str, }, DaoLockSizeMismatch { index: usize, }, ScriptHashTypeNotPermitted { hash_type: u8, }, InvalidScriptHashType { hash_type: Byte, }, Internal { description: String, },
}
The error types to transactions.

Variants



InsufficientCellCapacity

There is an erroneous output that its occupied capacity is greater than its capacity (output.occupied_capacity() > output.capacity()).

Fields

inner: TransactionErrorSource

The transaction field that causes error. It should always be TransactionErrorSource::Outputs.

index: usize

The index of that erroneous output.

occupied_capacity: Capacity

The occupied capacity of that erroneous output.

capacity: Capacity

The capacity of that erroneous output.



OutputsSumOverflow

The total capacity of outputs is less than the total capacity of inputs (SUM([o.capacity for o in outputs]) > SUM([i.capacity for i in inputs]).

Fields

inputs_sum: Capacity

The total capacity of inputs.

outputs_sum: Capacity

The total capacity of outputs.



Empty

Either inputs or outputs of the transaction are empty (inputs.is_empty() || outputs.is_empty()).

Fields

inner: TransactionErrorSource

The transaction field that causes the error. It should be TransactionErrorSource::Inputs or TransactionErrorSource::Outputs.



DuplicateCellDeps

There are duplicated CellDeps within the same transaction.

Fields

out_point: OutPoint

The out-point of that duplicated CellDep.



DuplicateHeaderDeps

There are duplicated HeaderDep within the same transaction.

Fields

hash: Byte32

The block hash of that duplicated HeaderDep.



OutputsDataLengthMismatch

The length of outputs is not equal to the length of outputs-data (outputs.len() != outputs_data.len()).

Fields

outputs_len: usize

The length of outputs.

outputs_data_len: usize

The length of outputs-data.



InvalidSince

Error dues to the fact that the since rule is not respected.

See also 0017-tx-valid-since.

Fields

index: usize

The index of input with invalid since field



Immature

The transaction is not mature yet, according to the since rule.

See also 0017-tx-valid-since.

Fields

index: usize

The index of input with immature since field.



CellbaseImmaturity

The transaction is not mature yet, according to the cellbase maturity rule.

Fields

inner: TransactionErrorSource

The transaction field that causes the error. It should be TransactionErrorSource::Inputs or TransactionErrorSource::CellDeps. It does not allow using an immature cell as input out-point and dependency out-point.

index: usize

The index of immature input out-point or dependency out-point.



MismatchedVersion

The transaction version does not match with the system expected.

Fields

expected: u32

The expected transaction version.

actual: u32

The actual transaction version.



ExceededMaximumBlockBytes

The transaction size exceeds limit.

Fields

limit: u64

The limited transaction size.

actual: u64

The actual transaction size.



Compatible

The compatible error.

Fields

feature: &'static str

The feature name.



DaoLockSizeMismatch

Nervos DAO lock size mismatch.

Fields

index: usize

The index of mismatched DAO cells.



ScriptHashTypeNotPermitted

The lock script hash type is not permitted by the current consensus rules.

Fields

hash_type: u8

The hash type value



InvalidScriptHashType

The lock Script hash_type field is invalid.

Fields

hash_type: Byte

The hash type value



Internal

The internal error.

Fields

description: String

The error description

Implementations

Source

impl TransactionError

pub fn is_malformed_tx(&self) -> bool

Returns whether this transaction error indicates that the transaction is malformed.